IosApp class

Details of a Firebase App for iOS.

Constructors

IosApp({String? apiKeyId, String? appId, String? appStoreId, String? bundleId, String? displayName, String? etag, String? expireTime, String? name, String? projectId, String? state, String? teamId})
IosApp.fromJson(Map json_)

Properties

apiKeyId ↔ String?
The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the IosApp.
getter/setter pair
appId ↔ String?
The globally unique, Firebase-assigned identifier for the IosApp.
getter/setter pair
appStoreId ↔ String?
The automatically generated Apple ID assigned to the iOS app by Apple in the iOS App Store.
getter/setter pair
bundleId ↔ String?
The canonical bundle ID of the iOS app as it would appear in the iOS AppStore.
getter/setter pair
displayName ↔ String?
The user-assigned display name for the IosApp.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and it may be sent with update requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
expireTime ↔ String?
Timestamp of when the App will be considered expired and cannot be undeleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the IosApp, in the format: projects/PROJECT_IDENTIFIER /iosApps/APP_ID * PROJECT_IDENTIFIER: the parent Project's [ProjectNumber](../projects#FirebaseProject.FIELDS.project_number) (recommended) or its [ProjectId](../projects#FirebaseProject.FIELDS.project_id).
getter/setter pair
projectId ↔ String?
A user-assigned unique identifier of the parent FirebaseProject for the IosApp.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The lifecycle state of the App.
getter/setter pair
teamId ↔ String?
The Apple Developer Team ID associated with the App in the App Store.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited