ListAvailableLocationsResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
locations ↔ List<Location>?
One page of results from a call to ListAvailableLocations.
getter/setter pair
nextPageToken ↔ String?
If the result list is too large to fit in a single response, then a token is returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited