RemoveIosAppRequest class

Constructors

RemoveIosAppRequest({bool? allowMissing, String? etag, bool? immediate, bool? validateOnly})
RemoveIosAppRequest.fromJson(Map json_)

Properties

allowMissing ↔ bool?
If set to true, and the App is not found, the request will succeed but no action will be taken on the server.
getter/setter pair
etag ↔ String?
Checksum provided in the IosApp resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
immediate ↔ bool?
Determines whether to immediately delete the IosApp.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
If set to true, the request is only validated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited