GoogleFirebaseAppcheckV1betaAttestationTokenResponse class

Encapsulates an App Check token, which are used to access Firebase services protected by App Check.

Properties

attestationToken ↔ String?
An App Check token.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ String?
The duration from the time this token is minted until its expiration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited