GoogleFirebaseAppcheckV1betaSafetyNetConfig class

An app's SafetyNet configuration object.

This configuration controls certain properties of the AppCheckToken returned by ExchangeSafetyNetToken, such as its ttl. Note that your registered SHA-256 certificate fingerprints are used to validate tokens issued by SafetyNet; please register them via the Firebase Console or programmatically via the Firebase Management Service.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The relative resource name of the SafetyNet configuration object, in the format: projects/{project_number}/apps/{app_id}/safetyNetConfig
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenTtl ↔ String?
Specifies the duration for which App Check tokens exchanged from SafetyNet tokens will be valid.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited