properties property
Properties of the Resource.
The values here will be representative of the properties available for
each resource type (see type). For example, a [Pub/Sub Topic
(pubsub.v1.topic)](https://cloud.google.com/pubsub/docs/reference/rest/v1/projects.topics)
can accept labels as a property; properties of a Topic could include
{ "labels": { "some_key": "some_value" } }
Required.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Map<core.String, core.Object?>>? properties;