ListVersionFilesResponse class

Constructors

ListVersionFilesResponse({List<VersionFile>? files, String? nextPageToken})
ListVersionFilesResponse.fromJson(Map json_)

Properties

files ↔ List<VersionFile>?
The list of paths to the hashes of the files in the specified version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The pagination token, if more results exist beyond the ones in this response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited