PathFilter class

A representation of filter path.

Constructors

PathFilter({List<String>? regexes})
PathFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
regexes ↔ List<String>?
An array of RegEx values by which to filter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited