Version class

A Version is a configuration and a collection of static files which determine how a site is displayed.

Constructors

Version({ServingConfig? config, String? createTime, ActingUser? createUser, String? deleteTime, ActingUser? deleteUser, String? fileCount, String? finalizeTime, ActingUser? finalizeUser, Map<String, String>? labels, String? name, String? status, String? versionBytes})
Version.fromJson(Map json_)

Properties

config ↔ ServingConfig?
The configuration for the behavior of the site.
getter/setter pair
createTime ↔ String?
The time at which the version was created.
getter/setter pair
createUser ↔ ActingUser?
Identifies the user who created the version.
getter/setter pair
deleteTime ↔ String?
The time at which the version was DELETED.
getter/setter pair
deleteUser ↔ ActingUser?
Identifies the user who DELETED the version.
getter/setter pair
fileCount ↔ String?
The total number of files associated with the version.
getter/setter pair
finalizeTime ↔ String?
The time at which the version was FINALIZED.
getter/setter pair
finalizeUser ↔ ActingUser?
Identifies the user who FINALIZED the version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels used for extra metadata and/or filtering.
getter/setter pair
name ↔ String?
The fully-qualified resource name for the version, in the format: sites/ SITE_ID/versions/VERSION_ID This name is provided in the response body when you call [CreateVersion](sites.versions/create).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The deploy status of the version.
getter/setter pair
versionBytes ↔ String?
The total stored bytesize of the version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited