File class

File containing source content.

Constructors

File({String? content, String? fingerprint, String? name})
File.fromJson(Map json_)

Properties

content ↔ String?
Textual Content.
getter/setter pair
fingerprint ↔ String?
Fingerprint (e.g. github sha) associated with the File.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
File name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited