Source class

Source is one or more File messages comprising a logical set of rules.

Constructors

Source({List<File>? files})
Source.fromJson(Map json_)

Properties

files ↔ List<File>?
File set constituting the Source bundle.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited