TestResult class

Test result message containing the state of the test as well as a description and source position for test failures.

Constructors

TestResult({List<String>? debugMessages, SourcePosition? errorPosition, List<ExpressionReport>? expressionReports, List<FunctionCall>? functionCalls, String? state, List<VisitedExpression>? visitedExpressions})
TestResult.fromJson(Map json_)

Properties

debugMessages ↔ List<String>?
Debug messages related to test execution issues encountered during evaluation.
getter/setter pair
errorPosition ↔ SourcePosition?
Position in the Source or Ruleset where the principle runtime error occurs.
getter/setter pair
expressionReports ↔ List<ExpressionReport>?
The mapping from expression in the ruleset AST to the values they were evaluated to.
getter/setter pair
functionCalls ↔ List<FunctionCall>?
The set of function calls made to service-defined methods.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the test. Possible string values are:
getter/setter pair
visitedExpressions ↔ List<VisitedExpression>?
The set of visited permission expressions for a given test.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited