BatchGetDocumentsRequest class

The request for Firestore.BatchGetDocuments.

Constructors

BatchGetDocumentsRequest({List<String>? documents, DocumentMask? mask, TransactionOptions? newTransaction, String? readTime, String? transaction})
BatchGetDocumentsRequest.fromJson(Map json_)

Properties

documents ↔ List<String>?
The names of the documents to retrieve.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mask ↔ DocumentMask?
The fields to return.
getter/setter pair
newTransaction ↔ TransactionOptions?
Starts a new transaction and reads the documents.
getter/setter pair
readTime ↔ String?
Reads documents as they were at the given time.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ String?
Reads documents in a transaction.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited