GoogleFirestoreAdminV1ListBackupsResponse class

The response for FirestoreAdmin.ListBackups.

Properties

backups ↔ List<GoogleFirestoreAdminV1Backup>?
List of all backups for the project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
List of locations that existing backups were not able to be fetched from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited