CommitResponse class

The response for Firestore.Commit.

Constructors

CommitResponse({String? commitTime, List<WriteResult>? writeResults})
CommitResponse.fromJson(Map json_)

Properties

commitTime ↔ String?
The time at which the commit occurred.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeResults ↔ List<WriteResult>?
The result of applying the writes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited