ExistenceFilter class

A digest of all the documents that match a given target.

Constructors

ExistenceFilter({int? count, int? targetId, BloomFilter? unchangedNames})
ExistenceFilter.fromJson(Map json_)

Properties

count ↔ int?
The total count of documents that match target_id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId ↔ int?
The target ID to which this filter applies.
getter/setter pair
unchangedNames ↔ BloomFilter?
A bloom filter that, despite its name, contains the UTF-8 byte encodings of the resource names of ALL the documents that match target_id, in the form projects/{project_id}/databases/{database_id}/documents/{document_path}.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited