FieldFilter class

A filter on a specific field.

Constructors

FieldFilter({FieldReference? field, String? op, Value? value})
FieldFilter.fromJson(Map json_)

Properties

field ↔ FieldReference?
The field to filter by.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
op ↔ String?
The operator to filter by. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Value?
The value to compare to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited