PartitionQueryRequest class

The request for Firestore.PartitionQuery.

Constructors

PartitionQueryRequest({int? pageSize, String? pageToken, String? partitionCount, String? readTime, StructuredQuery? structuredQuery})
PartitionQueryRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
The maximum number of partitions to return in this call, subject to partition_count.
getter/setter pair
pageToken ↔ String?
The next_page_token value returned from a previous call to PartitionQuery that may be used to get an additional set of results.
getter/setter pair
partitionCount ↔ String?
The desired maximum number of partition points.
getter/setter pair
readTime ↔ String?
Reads documents as they were at the given time.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredQuery ↔ StructuredQuery?
A structured query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited