ProjectsDatabasesResource class

Constructors

ProjectsDatabasesResource(ApiRequester client)

Properties

documents → ProjectsDatabasesDocumentsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexes → ProjectsDatabasesIndexesResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

exportDocuments(GoogleFirestoreAdminV1beta1ExportDocumentsRequest request, String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Exports a copy of all or a subset of documents from Google Cloud Firestore to another storage system, such as Google Cloud Storage.
importDocuments(GoogleFirestoreAdminV1beta1ImportDocumentsRequest request, String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Imports documents into Google Cloud Firestore.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited