RunQueryResponse class

The response for Firestore.RunQuery.

Constructors

RunQueryResponse({Document? document, bool? done, String? readTime, int? skippedResults, String? transaction})
RunQueryResponse.fromJson(Map json_)

Properties

document ↔ Document?
A query result, not set when reporting partial progress.
getter/setter pair
done ↔ bool?
If present, Firestore has completely finished the request and no more documents will be returned.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readTime ↔ String?
The time at which the document was read.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedResults ↔ int?
The number of results that have been skipped due to an offset between the last response and the current response.
getter/setter pair
transaction ↔ String?
The transaction that was started as part of this request.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited