Target class

A specification of a set of documents to listen to.

Constructors

Target({DocumentsTarget? documents, int? expectedCount, bool? once, QueryTarget? query, String? readTime, String? resumeToken, int? targetId})
Target.fromJson(Map json_)

Properties

documents ↔ DocumentsTarget?
A target specified by a set of document names.
getter/setter pair
expectedCount ↔ int?
The number of documents that last matched the query at the resume token or read time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
once ↔ bool?
If the target should be removed once it is current and consistent.
getter/setter pair
query ↔ QueryTarget?
A target specified by a query.
getter/setter pair
readTime ↔ String?
Start listening after a specific read_time.
getter/setter pair
resumeToken ↔ String?
A resume token from a prior TargetChange for an identical target.
getter/setter pair
resumeTokenAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId ↔ int?
The target ID that identifies the target on the stream.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited