TargetChange class

Targets being watched have changed.

Constructors

TargetChange({Status? cause, String? readTime, String? resumeToken, String? targetChangeType, List<int>? targetIds})
TargetChange.fromJson(Map json_)

Properties

cause ↔ Status?
The error that resulted in this change, if applicable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readTime ↔ String?
The consistent read_time for the given target_ids (omitted when the target_ids are not at a consistent snapshot).
getter/setter pair
resumeToken ↔ String?
A token that can be used to resume the stream for the given target_ids, or all targets if target_ids is empty.
getter/setter pair
resumeTokenAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetChangeType ↔ String?
The type of change that occurred. Possible string values are:
getter/setter pair
targetIds ↔ List<int>?
The target IDs of targets that have changed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited