Write class

A write on a document.

Constructors

Write({Precondition? currentDocument, String? delete, DocumentTransform? transform, Document? update, DocumentMask? updateMask, List<FieldTransform>? updateTransforms})
Write.fromJson(Map json_)

Properties

currentDocument ↔ Precondition?
An optional precondition on the document.
getter/setter pair
delete ↔ String?
A document name to delete.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform ↔ DocumentTransform?
Applies a transformation to a document.
getter/setter pair
update ↔ Document?
A document to write.
getter/setter pair
updateMask ↔ DocumentMask?
The fields to update in this write.
getter/setter pair
updateTransforms ↔ List<FieldTransform>?
The transforms to perform after update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited