GoogleCloudIdentitytoolkitV1QueryUserInfoRequest class

Request message for QueryUserInfo.

Properties

expression ↔ List<GoogleCloudIdentitytoolkitV1SqlExpression>?
Query conditions used to filter results.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ String?
The maximum number of accounts to return with an upper limit of 500.
getter/setter pair
offset ↔ String?
The number of accounts to skip from the beginning of matching records.
getter/setter pair
order ↔ String?
The order for sorting query result.
getter/setter pair
returnUserInfo ↔ bool?
If true, this request will return the accounts matching the query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortBy ↔ String?
The field to use for sorting user accounts.
getter/setter pair
tenantId ↔ String?
The ID of the tenant to which the result is scoped.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited