GoogleCloudIdentitytoolkitV1QueryUserInfoResponse class

Response message for QueryUserInfo.

Properties

hashCode → int
The hash code for this object.
no setterinherited
recordsCount ↔ String?
If return_user_info in the request is true, this is the number of returned accounts in this message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInfo ↔ List<GoogleCloudIdentitytoolkitV1UserInfo>?
If return_user_info in the request is true, this is the accounts matching the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited