$Precondition class

Used by:

  • firestore:v1 : Precondition
  • firestore:v1beta1 : Precondition

Constructors

$Precondition({bool? exists, String? updateTime})
$Precondition.fromJson(Map json_)

Properties

exists ↔ bool?
When set to true, the target document must exist.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
When set, the target document must exist and have been last updated at that time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited