$RollbackRequest class

Used by:

  • firestore:v1 : RollbackRequest
  • firestore:v1beta1 : RollbackRequest

Constructors

$RollbackRequest({String? transaction})
$RollbackRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ String?
The transaction to roll back.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited