BucketAutoclass class

The bucket's Autoclass configuration.

Constructors

BucketAutoclass({bool? enabled, DateTime? toggleTime})
BucketAutoclass.fromJson(Map json_)

Properties

enabled ↔ bool?
Whether or not Autoclass is enabled on this bucket
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toggleTime ↔ DateTime?
A date and time in RFC 3339 format representing the instant at which "enabled" was last toggled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited