ApkManifest class

Constructors

ApkManifest({String? applicationLabel, List<IntentFilter>? intentFilters, int? maxSdkVersion, List<Metadata>? metadata, int? minSdkVersion, String? packageName, List<Service>? services, int? targetSdkVersion, List<UsesFeature>? usesFeature, List<String>? usesPermission, String? versionCode, String? versionName})
ApkManifest.fromJson(Map json_)

Properties

applicationLabel ↔ String?
User-readable name for the application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intentFilters ↔ List<IntentFilter>?
getter/setter pair
maxSdkVersion ↔ int?
Maximum API level on which the application is designed to run.
getter/setter pair
metadata ↔ List<Metadata>?
Meta-data tags defined in the manifest.
getter/setter pair
minSdkVersion ↔ int?
Minimum API level required for the application to run.
getter/setter pair
packageName ↔ String?
Full Java-style package name for this application, e.g. "com.example.foo".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services ↔ List<Service>?
Services contained in the tag.
getter/setter pair
targetSdkVersion ↔ int?
Specifies the API Level on which the application is designed to run.
getter/setter pair
usesFeature ↔ List<UsesFeature>?
Feature usage tags defined in the manifest.
getter/setter pair
usesPermission ↔ List<String>?
Permissions declared to be used by the application
getter/setter pair
versionCode ↔ String?
Version number used internally by the app.
getter/setter pair
versionName ↔ String?
Version number shown to users.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited