IosDeviceCatalog class

The currently supported iOS devices.

Constructors

IosDeviceCatalog({List<IosModel>? models, IosRuntimeConfiguration? runtimeConfiguration, List<IosVersion>? versions, List<XcodeVersion>? xcodeVersions})
IosDeviceCatalog.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
models ↔ List<IosModel>?
The set of supported iOS device models.
getter/setter pair
runtimeConfiguration ↔ IosRuntimeConfiguration?
The set of supported runtime configurations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versions ↔ List<IosVersion>?
The set of supported iOS software versions.
getter/setter pair
xcodeVersions ↔ List<XcodeVersion>?
The set of supported Xcode versions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited