IosRoboTest class

A test that explores an iOS application on an iOS device.

Constructors

IosRoboTest({String? appBundleId, FileReference? appIpa, FileReference? roboScript})
IosRoboTest.fromJson(Map json_)

Properties

appBundleId ↔ String?
The bundle ID for the app-under-test.
getter/setter pair
appIpa ↔ FileReference?
The ipa stored at this file should be used to run the test.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
roboScript ↔ FileReference?
An optional Roboscript to customize the crawl.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited